"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var build_exports = {};
__export(build_exports, {
  default: () => build_default
});
module.exports = __toCommonJS(build_exports);
var import_fs_extra = __toESM(require("fs-extra"));
var import_picocolors = __toESM(require("picocolors"));
var import_webpack = __toESM(require("webpack"));
var import_checkRequiredFiles = __toESM(require("react-dev-utils/checkRequiredFiles"));
var import_formatWebpackMessages = __toESM(require("react-dev-utils/formatWebpackMessages"));
var import_FileSizeReporter = __toESM(require("react-dev-utils/FileSizeReporter"));
var import_printBuildError = __toESM(require("react-dev-utils/printBuildError"));
var import_browsersHelper = require("react-dev-utils/browsersHelper");
var import_getEnv = require("../config/getEnv");
var import_getPaths = require("../config/getPaths");
var import_webpack2 = require("../config/webpack.config");
process.on("unhandledRejection", (err) => {
  throw err;
});
const WARN_AFTER_BUNDLE_GZIP_SIZE = 512 * 1024;
const WARN_AFTER_CHUNK_GZIP_SIZE = 1024 * 1024;
const copyPublicFolder = async () => {
  const paths = (0, import_getPaths.getPaths)();
  await import_fs_extra.default.copy(paths.appPublic, paths.appDist, {
    dereference: true,
    filter: (file) => file !== paths.appHtml
  });
};
const webpackBuild = async (config) => {
  console.log(import_picocolors.default.cyan("\nCreating an optimized production build..."));
  const compiler = (0, import_webpack.default)(config);
  return new Promise((resolve, reject) => {
    compiler.run((err, stats) => {
      let messages;
      if (err) {
        if (!err.message) {
          return reject(err);
        }
        let errMessage = err.message;
        if (Object.prototype.hasOwnProperty.call(err, "postcssNode")) {
          errMessage += "\nCompileError: Begins at CSS selector " + err["postcssNode"].selector;
        }
        messages = (0, import_formatWebpackMessages.default)({
          errors: [errMessage],
          warnings: []
        });
      } else {
        messages = (0, import_formatWebpackMessages.default)(
          stats?.toJson({ all: false, warnings: true, errors: true })
        );
      }
      if (messages.errors.length) {
        if (messages.errors.length > 1) {
          messages.errors.length = 1;
        }
        return reject(new Error(messages.errors.join("\n\n")));
      }
      const resolveArgs = {
        stats,
        warnings: messages.warnings
      };
      return resolve(resolveArgs);
    });
  });
};
const build = async (mode) => {
  try {
    (0, import_getEnv.applyEnv)(mode, "production");
    const isInteractive = process.stdout.isTTY;
    const paths = (0, import_getPaths.getPaths)();
    if (!(0, import_checkRequiredFiles.default)([paths.appHtml, paths.appIndexJs])) {
      process.exit(1);
    }
    await (0, import_browsersHelper.checkBrowsers)(paths.appPath, isInteractive);
    const previousFileSizes = await import_FileSizeReporter.default.measureFileSizesBeforeBuild(paths.appDist);
    await import_fs_extra.default.emptyDir(paths.appDist);
    await copyPublicFolder();
    try {
      const { stats, warnings } = await webpackBuild((0, import_webpack2.getWebpackConfig)());
      if (warnings.length) {
        console.log(import_picocolors.default.yellow("Compiled with warnings.\n"));
        console.log(warnings.join("\n\n"));
        console.log(
          "\nSearch for the " + import_picocolors.default.underline(import_picocolors.default.yellow("keywords")) + " to learn more about each warning."
        );
        console.log(
          "To ignore, add " + import_picocolors.default.cyan("// eslint-disable-next-line") + " to the line before.\n"
        );
      } else {
        console.log(import_picocolors.default.green("Compiled successfully.\n"));
      }
      console.log("File sizes after gzip:\n");
      import_FileSizeReporter.default.printFileSizesAfterBuild(
        stats,
        previousFileSizes,
        paths.appDist,
        WARN_AFTER_BUNDLE_GZIP_SIZE,
        WARN_AFTER_CHUNK_GZIP_SIZE
      );
      console.log();
    } catch (err) {
      console.log(import_picocolors.default.red("Failed to compile.\n"));
      (0, import_printBuildError.default)(err);
      process.exit(1);
    }
  } catch (err) {
    if (err && err.message) {
      console.log(err.message);
    }
    process.exit(1);
  }
};
var build_default = build;
